@@ -8,15 +8,17 @@ class MinimalConfluence:
         self.username = username
         self.password = password
 
-        self.api = tortilla.wrap(self.host, auth=HTTPBasicAuth(self.username, self.password))
+        self.api = tortilla.wrap(
+            self.host, auth=HTTPBasicAuth(self.username, self.password)
+        )
 
     def get_page(self, title=None, space_key=None, page_id=None):
         if page_id is not None:
             return self.api.content.get(page_id)
         elif title is not None:
-            params = {'title': title}
+            params = {"title": title}
             if space_key is not None:
-                params['spaceKey'] = space_key
+                params["spaceKey"] = space_key
 
             response = self.api.content.get(params=params)
 
@@ -45,45 +47,45 @@ class MinimalConfluence:
 
         """
         page_structure = {
-            'title': title,
-            'type': 'page',
-            'space': {
-                'key': space
-            },
-            'body': {
-                'storage': {
-                    'value': body,
-                    'representation': 'storage'
-                }
-            }
+            "title": title,
+            "type": "page",
+            "space": {"key": space},
+            "body": {"storage": {"value": body, "representation": "storage"}},
         }
 
         if parent_id is not None:
             if type(parent_id) is str:
                 parent_id = int(parent_id)
-            page_structure['ancestors'] = [{'id': parent_id}]
+            page_structure["ancestors"] = [{"id": parent_id}]
 
         if update_message is not None:
-            page_structure['version'] = {'message': update_message}
+            page_structure["version"] = {"message": update_message}
 
         return self.api.content.post(json=page_structure)
 
-    def update_page(self, page, body, update_message=None):
+    def update_page(self, page, body, parent_id=None, update_message=None):
         update_structure = {
-            'version': {
-                'number': page.version.number + 1,
-            },
-            'title': page.title,
-            'type': 'page',
-            'body': {
-                'storage': {
-                    'value': body,
-                    'representation': 'storage'
-                }
-            }
+            "version": {"number": page.version.number + 1,},
+            "title": page.title,
+            "type": "page",
+            "body": {"storage": {"value": body, "representation": "storage"}},
         }
 
+        if parent_id is not None:
+            if type(parent_id) is str:
+                parent_id = int(parent_id)
+            update_structure["ancestors"] = [{"id": parent_id}]
+
         if update_message is not None:
-            update_structure['version']['message'] = update_message
+            update_structure["version"]["message"] = update_message
 
         return self.api.content.put(page.id, json=update_structure)
+
+    def upload_attachment(self, page, fp):
+        return self.api.content(page.id).child.post(
+            "attachment",
+            format=(None, "json"),
+            headers={"X-Atlassian-Token": "nocheck"},
+            params={"allowDuplicated": "true"},
+            files={"file": fp},
+        )
